﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Web.UI.WebControls;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WebForms;

namespace _8551
{
    public partial class WebForm1 : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                Map1.MapUnit = GeographyUnit.DecimalDegree;
                Map1.CurrentExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);
                Map1.MapBackground = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));

                // Base map
                WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay();
                Map1.CustomOverlays.Add(worldMapKitOverlay);

                // City layer
                ShapeFileFeatureLayer shapeLayer = new ShapeFileFeatureLayer(Server.MapPath("~/App_Data/MajorCities.shp"));
                shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColor.SimpleColors.Red), 10);
                shapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                
                LayerOverlay overlay = new LayerOverlay();
                overlay.Layers.Add(shapeLayer);
                Map1.CustomOverlays.Add(overlay);
                                                
                shapeLayer.Open();
                Collection<Feature> allFeatures = shapeLayer.FeatureSource.GetAllFeatures(ReturningColumnsType.AllColumns);
                List<string> names = new List<string>();
                foreach (var item in allFeatures)
                {
                    names.Add(item.ColumnValues["AREANAME"]);
                }
                shapeLayer.Close();

                Features_Cb.DataSource = names;
                Features_Cb.DataBind();
                                
                foreach (ListItem item in Features_Cb.Items)
                {
                    item.Selected = true;
                }
            }
        }

        protected void Features_Cb_SelectedIndexChanged(object sender, EventArgs e)
        {
            ShapeFileFeatureLayer featureLayer = ((ShapeFileFeatureLayer)(((LayerOverlay)Map1.CustomOverlays[1]).Layers[0]));
            featureLayer.Open();
            var toHideItems = new Collection<string>();
            foreach (var item in Features_Cb.Items)
            {
                if (!((ListItem)item).Selected)
                {
                    toHideItems.Add(item.ToString());
                }
            }

            featureLayer.FeatureIdsToExclude.Clear();
            foreach (var item in toHideItems)
            {
                featureLayer.FeatureIdsToExclude.Add(featureLayer.FeatureSource.GetFeaturesByColumnValue("AREANAME", item)[0].Id);
            }
        }

        protected void HideAll_Click(object sender, EventArgs e)
        {
            // Set CheckBox status
            foreach (ListItem item in Features_Cb.Items)
            {
                item.Selected = false;
            }

            // Set status on map
            ShapeFileFeatureLayer featureLayer = ((ShapeFileFeatureLayer)(((LayerOverlay)Map1.CustomOverlays[1]).Layers[0]));
            featureLayer.Open();
            Collection<Feature> features = featureLayer.FeatureSource.GetAllFeatures(ReturningColumnsType.AllColumns);
            featureLayer.Close();

            foreach (Feature feature in features)
            {
                featureLayer.FeatureIdsToExclude.Add(feature.Id);
            }
        }

        protected void ShowAll_Click(object sender, EventArgs e)
        {
            // Set CheckBox status
            foreach (ListItem item in Features_Cb.Items)
            {
                item.Selected = true;
            }

            // Set status on map
            ShapeFileFeatureLayer featureLayer = ((ShapeFileFeatureLayer)(((LayerOverlay)Map1.CustomOverlays[1]).Layers[0]));
            featureLayer.FeatureIdsToExclude.Clear();
        }
    }
}